@@ -5,7 +5,7 @@ use crate::window::{Application, Frame};
 #[cfg(windows)]
 #[cfg(not(feature="nxui-awc"))]
 /// Run nxui::window::Application
-pub fn run_app(application: Box<dyn Application>) {
+pub fn create_new_app(application: Box<dyn Application>) {
     // Get window title
     let app_name = application.app_name();
     // Get attributes
@@ -74,7 +74,7 @@ pub fn run_app(application: Box<dyn Application>) {
 #[cfg(windows)]
 #[cfg(feature="nxui-awc")]
 /// Run nxui::window::Application
-pub fn run_app(application: Box<dyn Application>) {
+pub fn create_new_app(application: Box<dyn Application>) {
     // Get window title
     let app_name = application.app_name();
     // Get attributes
@@ -83,7 +83,9 @@ pub fn run_app(application: Box<dyn Application>) {
     let advanced_options = application.advanced_options();
     let storage = Storage::new(get_app_dirs(app_name));
     // startup process
-    application.startup(storage);
+    if attributes.is_childwindow == false {
+        application.startup(storage);
+    }
 
     // Create a window
     use windows_sys::{Win32::Foundation::*, Win32::Graphics::Gdi::ValidateRect, Win32::System::LibraryLoader::GetModuleHandleA, Win32::UI::WindowsAndMessaging::*};
@@ -128,7 +130,6 @@ pub fn run_app(application: Box<dyn Application>) {
         let win = CreateWindowExA(advanced_options.get_style(), "window".as_ptr(), attributes.title.as_ptr(), attributes.style, attributes.x, attributes.y, attributes.width, attributes.height, 0, 0, instance, std::ptr::null_mut());
 
         let frame = Frame::new(win);
-
         application.ui(frame);
 
         let mut message = std::mem::zeroed();
@@ -145,7 +146,7 @@ pub fn run_app(application: Box<dyn Application>) {
 #[cfg(unix)]
 #[cfg(not(feature="nxui-awc"))]
 /// Run nxui::window::Application
-pub fn run_app(application: Box<dyn Application>) {
+pub fn create_new_app(application: Box<dyn Application>) {
     // Get window title
     let app_name = application.app_name();
     // Get attributes
@@ -182,7 +183,7 @@ pub fn run_app(application: Box<dyn Application>) {
 #[cfg(unix)]
 #[cfg(feature="nxui-awc")]
 /// Run nxui::window::Application
-pub fn run_app(application: Box<dyn Application>) {
+pub fn create_new_app(application: Box<dyn Application>) {
     // Get window title
     let app_name = application.app_name();
     // Get attributes
@@ -202,6 +203,7 @@ pub fn run_app(application: Box<dyn Application>) {
     window.set_title(attributes.title.as_str());
     window.set_default_size(attributes.width,attributes.height);
     window.set_window_position(gtk::WindowPosition::Center);
+    window.set_type_hint(advanced_options.get_style());
 
     window.connect_delete_event(|_, _| {
         gtk::main_quit();
