@@ -1,7 +1,7 @@
 use crate::io::storage::Storage;
 use crate::messagebox::MessageBox;
 use crate::natives_and_messaging::*;
-use crate::window::{AdvancedOptions, Application, Frame, WindowAttributes};
+use crate::window::{Application, Frame, WindowAttributes};
 
 pub struct DemoWindow {
 
