@@ -99,6 +99,7 @@ impl Default for Frame {
 }
 
 #[cfg(windows)]
+#[deprecated(since="0.10.4", note="Please use the Attributes struct instead")]
 pub struct WindowAttributes {
     pub style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,
     pub title: String,
@@ -110,6 +111,7 @@ pub struct WindowAttributes {
 }
 
 #[cfg(windows)]
+#[deprecated(since="0.10.4", note="Please use the Attributes struct instead")]
 impl WindowAttributes {
     pub fn new(style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,title: String,width: i32,height: i32,x: i32,y: i32,is_childwindow: bool) -> Self {
         Self {
@@ -124,6 +126,30 @@ impl WindowAttributes {
     }
 }
 
+#[cfg(windows)]
+pub struct Attributes {
+    pub style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,
+    pub title: String,
+    pub width: i32,
+    pub height: i32,
+    pub x: i32,
+    pub y: i32,
+}
+
+#[cfg(windows)]
+impl Attributes {
+    pub fn new(style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,title: String,width: i32,height: i32,x: i32,y: i32) -> Self {
+        Self {
+            style,
+            title,
+            width,
+            height,
+            x,
+            y
+        }
+    }
+}
+
 #[cfg(windows)]
 #[cfg(feature="nxui-awc")]
 pub struct AdvancedOptions {
